@@ -1,15 +1,18 @@
 #' @rdname find_parameters.BGGM
 #' @export
-find_parameters.brmsfit <- function(x,
-                                    effects = "all",
-                                    component = "all",
-                                    flatten = FALSE,
-                                    parameters = NULL,
-                                    ...) {
+find_parameters.brmsfit <- function(
+  x,
+  effects = "all",
+  component = "all",
+  flatten = FALSE,
+  parameters = NULL,
+  ...
+) {
   effects <- validate_argument(
     effects,
     c("all", "fixed", "random", "random_variance", "grouplevel", "full")
   )
+  # fmt: skip
   component <- validate_argument(
     component,
     c(
@@ -64,7 +67,6 @@ find_parameters.brmsfit <- function(x,
 
 # utilities ------------------------------------------------------------
 
-
 .brms_elements <- function(effects, component, dpars) {
   # elements to return
   elements <- .get_elements(effects = effects, component = component)
@@ -83,7 +85,8 @@ find_parameters.brmsfit <- function(x,
   }
 
   # remove random effects or keep them only
-  switch(effects,
+  switch(
+    effects,
     fixed = elements[!endsWith(elements, "random")],
     grouplevel = ,
     random_variance = ,
@@ -106,7 +109,10 @@ find_parameters.brmsfit <- function(x,
     mv_pattern_random_dpars <- "\\["
   } else {
     mv_pattern_fixed <- sprintf("(\\Q%s\\E_)", mv_response)
-    mv_pattern_random_dpars <- mv_pattern_random <- sprintf("(_\\Q%s\\E)(_|\\[)", mv_response)
+    mv_pattern_random_dpars <- mv_pattern_random <- sprintf(
+      "(_\\Q%s\\E)(_|\\[)",
+      mv_response
+    )
     mv_pattern_dpars <- sprintf("(\\Q%s\\E_)", mv_response)
     mv_pattern_sigma <- sprintf("\\Q%s\\E", mv_response)
   }
@@ -148,7 +154,8 @@ find_parameters.brmsfit <- function(x,
   cond_random <- c(rand, rand_sd, rand_cor, car_struc)
 
   # check whether group level effects should be returned or not.
-  cond_random <- switch(effects,
+  cond_random <- switch(
+    effects,
     all = ,
     fixed = ,
     random_variance = cond_random[!startsWith(cond_random, "r_")],
@@ -163,6 +170,7 @@ find_parameters.brmsfit <- function(x,
   for (dp in dpars) {
     random_dp <- NULL
     # fixed
+    # fmt: skip
     if (dp == "sigma") {
       # exception: sigma
       dpars_fixed[[dp]] <- fe[fe == "sigma"]
@@ -184,7 +192,8 @@ find_parameters.brmsfit <- function(x,
     dpars_random[[dp]] <- compact_character(random_dp)
 
     # check whether group level effects should be returned or not.
-    dpars_random[[dp]] <- switch(effects,
+    dpars_random[[dp]] <- switch(
+      effects,
       all = ,
       fixed = ,
       random_variance = dpars_random[[dp]][!startsWith(dpars_random[[dp]], "r_")],
