@@ -6,9 +6,9 @@
 #'   variable) in a regression formula. Optionally, all model terms can also be
 #'   checked for any such transformation. Currently, following patterns are
 #'   detected: `log`, `log1p`, `log2`, `log10`, `exp`, `expm1`, `sqrt`,
-#'   `log(y+<number>)`, `log-log`, `power` (e.g. to 2nd power, like `I(y^2)`),
-#'   `inverse` (like `1/y`), `scale` (e.g., `y/3`), and `box-cox` (e-g-,
-#'   `(y^lambda - 1) / lambda`).
+#'   `log(y+<number>)`, `log-log`, `log(y,base=<number>)`, `power` (e.g. to 2nd
+#'   power, like `I(y^2)`), `inverse` (like `1/y`), `scale` (e.g., `y/3`), and
+#'   `box-cox` (e.g., `(y^lambda - 1) / lambda`).
 #'
 #' @param x A regression model or a character string of the formulation of the
 #' (response) variable.
@@ -103,6 +103,7 @@ find_transformation.character <- function(x, ...) {
       transform_fun <- "log-log"
     } else {
       plus_minus <- NULL
+      base_value <- NULL
       # make sure we definitly have a "+" in the log-transformation
       if (grepl("+", x, fixed = TRUE)) {
         # 1. try: log(x + number)
@@ -115,9 +116,27 @@ find_transformation.character <- function(x, ...) {
             eval(parse(text = gsub("log\\(([^,\\+)]*)(.*)\\)", "\\1", x)))
           )
         }
+      } else if (grepl(",", x, fixed = TRUE)) {
+        # check if we have log() with base-definition (e.g. `log(x, base = 5)`)
+        base_value <- trim_ws(gsub(
+          ",",
+          "",
+          gsub("log\\(([^,\\+)]*)(.*)\\)", "\\2", x),
+          fixed = TRUE
+        ))
+        if (startsWith(base_value, "base")) {
+          base_value <- suppressWarnings(as.numeric(trim_ws(
+            gsub("base", "", gsub("=", "", base_value, fixed = TRUE), fixed = TRUE)
+          )))
+        }
       }
-      if (is.null(plus_minus) || is.function(plus_minus)) {
+      if (
+        (is.null(plus_minus) || is.function(plus_minus)) &&
+          (is.null(base_value) || is.na(base_value))
+      ) {
         transform_fun <- "log"
+      } else if (!is.null(base_value) && !is.na(base_value)) {
+        transform_fun <- paste0("log(x,base=", base_value, ")")
       } else {
         transform_fun <- paste0("log(x+", plus_minus, ")")
       }
@@ -169,7 +188,8 @@ find_transformation.character <- function(x, ...) {
 # helper -----------------------------
 
 .is_division <- function(x) {
-  any(grepl("(.*)/([0-9\\.\\+\\-]+)(\\)*)$", x)) && !any(grepl("(.*)(\\^|\\*\\*)\\((.*)/(.*)\\)", x))
+  any(grepl("(.*)/([0-9\\.\\+\\-]+)(\\)*)$", x)) &&
+    !any(grepl("(.*)(\\^|\\*\\*)\\((.*)/(.*)\\)", x))
 }
 
 .is_box_cox <- function(x) {
