@@ -14,17 +14,25 @@
 #' @export
 get_predictors <- function(x, verbose = TRUE) {
   vars <- if (inherits(x, "wbm")) {
-    unlist(compact_list(find_terms(x, flatten = FALSE)[c("conditional", "instruments")]))
+    unlist(compact_list(
+      find_terms(x, flatten = FALSE, verbose = FALSE)[c("conditional", "instruments")]
+    ))
   } else {
-    find_predictors(x, effects = "fixed", component = "all", flatten = TRUE)
+    find_predictors(
+      x,
+      effects = "fixed",
+      component = "all",
+      flatten = TRUE,
+      verbose = FALSE
+    )
   }
 
-  dat <- get_data(x)
+  dat <- get_data(x, verbose = FALSE)
   dat <- dat[, intersect(vars, colnames(dat)), drop = FALSE]
 
   if (is_empty_object(dat)) {
     if (isTRUE(verbose)) {
-      warning(format_message("Data frame is empty, probably you have an intercept-only model?"), call. = FALSE)
+      format_warning("Data frame is empty, probably you have an intercept-only model?")
     }
     return(NULL)
   }
