@@ -4,7 +4,8 @@
 #' @description `is_converged()` provides an alternative convergence
 #'   test for `merMod`-objects.
 #'
-#' @param x A model object from class `merMod`, `glmmTMB`, `glm` or `_glm`.
+#' @param x A model object from class `merMod`, `glmmTMB`, `glm`, `lavaan` or
+#' `_glm`.
 #' @param tolerance Indicates up to which value the convergence result is
 #'   accepted. The smaller `tolerance` is, the stricter the test will be.
 #' @param ... Currently not used.
@@ -26,13 +27,17 @@
 #' convergence test for `merMod`-objects.
 #'
 #' @section Resolving convergence issues:
-#' Convergence issues are not easy to diagnose. The help page on `?lme4::convergence`
-#' provides most of the current advice about how to resolve convergence issues.
-#' Another clue might be large parameter values, e.g. estimates (on the scale of
-#' the linear predictor) larger than 10 in (non-identity link) generalized linear
-#' model *might* indicate complete separation, which can be addressed by
-#' regularization, e.g. penalized regression or Bayesian regression with
-#' appropriate priors on the fixed effects.
+#' Convergence issues are not easy to diagnose. The help page on
+#' `?lme4::convergence` provides most of the current advice about how to resolve
+#' convergence issues. In general, convergence issues may be addressed by one or
+#' more of the following strategies: 1. Rescale continuous predictors; 2. try a
+#' different optimizer; 3. increase the number of iterations; or, if everything
+#' else fails, 4. simplify the model. Another clue might be large parameter
+#' values, e.g. estimates (on the scale of the linear predictor) larger than 10
+#' in (non-identity link) generalized linear model *might* indicate complete
+#' separation, which can be addressed by regularization, e.g. penalized
+#' regression or Bayesian regression with appropriate priors on the fixed
+#' effects.
 #'
 #' @section Convergence versus Singularity:
 #' Note the different meaning between singularity and convergence: singularity
@@ -40,9 +45,16 @@
 #' likelihood estimation for the variance-covariance matrix of the random effects
 #' is positive definite or only semi-definite. Convergence is a question of
 #' whether we can assume that the numerical optimization has worked correctly
-#' or not.
+#' or not. A convergence failure means the optimizer (the algorithm) could not
+#' find a stable solution (_Bates et. al 2015_).
+#'
+#' @references
+#' Bates, D., Mächler, M., Bolker, B., and Walker, S. (2015). Fitting Linear
+#' Mixed-Effects Models Using lme4. Journal of Statistical Software, 67(1),
+#' 1-48. \doi{10.18637/jss.v067.i01}
 #'
 #' @examplesIf require("lme4", quietly = TRUE)
+#' library(lme4)
 #' data(cbpp)
 #' set.seed(1)
 #' cbpp$x <- rnorm(nrow(cbpp))
@@ -58,6 +70,7 @@
 #'
 #' @examplesIf getOption("warn") < 2L && require("glmmTMB")
 #' \donttest{
+#' library(glmmTMB)
 #' model <- glmmTMB(
 #'   Sepal.Length ~ poly(Petal.Width, 4) * poly(Petal.Length, 4) +
 #'     (1 + poly(Petal.Width, 4) | Species),
@@ -74,7 +87,10 @@ is_converged <- function(x, tolerance = 0.001, ...) {
 
 #' @export
 is_converged.default <- function(x, tolerance = 0.001, ...) {
-  format_alert(sprintf("`is_converged()` does not work for models of class '%s'.", class(x)[1]))
+  format_alert(sprintf(
+    "`is_converged()` does not work for models of class '%s'.",
+    class(x)[1]
+  ))
 }
 
 
