@@ -11,7 +11,11 @@ test_that("get_predicted - lm", {
   rezlink <- get_predicted(x, predict = "link", ci = 0.95)
   rezrela <- get_predicted(x, predict = "expectation", ci = 0.95)
   expect_equal(mean(abs(rezlink - rezrela)), 0, tolerance = 1e-3)
-  expect_equal(mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high), 0, tolerance = 1e-3)
+  expect_equal(
+    mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high),
+    0,
+    tolerance = 1e-3
+  )
 
   # Relation vs. Prediction
   rezpred <- get_predicted(x, predict = "prediction", ci = 0.95)
@@ -40,8 +44,16 @@ test_that("get_predicted - lm", {
   rez <- get_predicted(x, iterations = 600, ci = 0.95)
   expect_length(rez, 32)
   expect_null(nrow(rez))
-  expect_equal(mean(abs(as.data.frame(ref$fit)$fit - summary(rez)$Predicted)), 0, tolerance = 0.1)
-  expect_equal(mean(abs(as.data.frame(ref$fit)$lwr - summary(rez)$CI_low)), 0, tolerance = 0.5)
+  expect_equal(
+    mean(abs(as.data.frame(ref$fit)$fit - summary(rez)$Predicted)),
+    0,
+    tolerance = 0.1
+  )
+  expect_equal(
+    mean(abs(as.data.frame(ref$fit)$lwr - summary(rez)$CI_low)),
+    0,
+    tolerance = 0.5
+  )
   # TODO: Is it possible to get "prediction" CIs via bootstrapping?
 
   skip_if_not_installed("rstanarm")
@@ -82,7 +94,10 @@ test_that("get_predicted - glm", {
   expect_identical(nrow(rez), 32L)
   expect_equal(max(abs(ref$fit - rez$Predicted)), 0, tolerance = 1e-4)
   expect_equal(max(abs(ref$se.fit - rez$SE)), 0, tolerance = 1e-4)
-  ref <- as.data.frame(suppressWarnings(link_inverse(x)(predict.lm(x, interval = "confidence"))))
+  ref <- as.data.frame(suppressWarnings(link_inverse(x)(predict.lm(
+    x,
+    interval = "confidence"
+  ))))
   expect_equal(max(abs(ref$lwr - rez$CI_low)), 0, tolerance = 1e-2)
 
   ref <- predict(x, se.fit = TRUE, type = "link")
@@ -95,13 +110,24 @@ test_that("get_predicted - glm", {
   skip_if_not_installed("boot")
   set.seed(333)
   ref <- suppressWarnings(predict(x, se.fit = TRUE, type = "response"))
-  rez <- suppressWarnings(summary(get_predicted(x, iterations = 800, verbose = FALSE, ci = 0.95)))
+  rez <- suppressWarnings(summary(get_predicted(
+    x,
+    iterations = 800,
+    verbose = FALSE,
+    ci = 0.95
+  )))
   expect_equal(mean(abs(ref$fit - rez$Predicted)), 0, tolerance = 0.1)
 
   skip_if_not_installed("rstanarm")
 
   # vs. Bayesian
-  xbayes <- rstanarm::stan_glm(vs ~ wt, data = mtcars, family = "binomial", refresh = 0, seed = 333)
+  xbayes <- rstanarm::stan_glm(
+    vs ~ wt,
+    data = mtcars,
+    family = "binomial",
+    refresh = 0,
+    seed = 333
+  )
   rez <- as.data.frame(get_predicted(x, predict = "link", ci = 0.95))
   rezbayes <- summary(get_predicted(xbayes, predict = "link", ci = 0.95))
   expect_equal(mean(abs(rez$Predicted - rezbayes$Predicted)), 0, tolerance = 0.1)
@@ -162,12 +188,17 @@ test_that("robust vcov", {
   expect_true(all(se1 == se2))
   expect_true(all(se1 == se3))
   # hardcoded values obtained before vcov_estimation was deprecated
-  expect_equal(head(se1), c(
-    0.862974605863594, 0.862974605863594,
-    1.04476534302177, 0.862974605863594,
-    0.942213270105983, 0.911147902473696
-  ),
-  ignore_attr = TRUE
+  expect_equal(
+    head(se1),
+    c(
+      0.862974605863594,
+      0.862974605863594,
+      1.04476534302177,
+      0.862974605863594,
+      0.942213270105983,
+      0.911147902473696
+    ),
+    ignore_attr = TRUE
   )
   # various user inputs
   se1 <- get_predicted_se(mod, vcov = "HC2")
@@ -201,7 +232,11 @@ test_that("get_predicted - lmerMod", {
   skip_if_not_installed("rstanarm")
 
   suppressPackageStartupMessages({
-    suppressWarnings(suppressMessages(library(rstanarm, quietly = TRUE, warn.conflicts = FALSE))) # nolint
+    suppressWarnings(suppressMessages(library(
+      rstanarm,
+      quietly = TRUE,
+      warn.conflicts = FALSE
+    ))) # nolint
   })
 
   x <- lme4::lmer(mpg ~ am + (1 | cyl), data = mtcars)
@@ -211,7 +246,11 @@ test_that("get_predicted - lmerMod", {
   rezrela <- get_predicted(x, predict = "expectation", ci = 0.95)
   rezpred <- get_predicted(x, predict = "prediction", ci = 0.95)
   expect_equal(mean(abs(rezlink - rezrela)), 0, tolerance = 1e-3)
-  expect_equal(mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high), 0, tolerance = 1e-3)
+  expect_equal(
+    mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high),
+    0,
+    tolerance = 1e-3
+  )
   expect_true(all(summary(rezlink)$CI_high - summary(rezpred)$CI_high < 0))
 
   # Bootstrap
@@ -219,11 +258,13 @@ test_that("get_predicted - lmerMod", {
   rez <- as.data.frame(get_predicted(x, iterations = 5, ci = 0.95))
   expect_identical(c(nrow(rez), ncol(rez)), c(32L, 9L))
 
-
   # Compare to merTools
   rez_merTools <- merTools::predictInterval(x, level = 0.95, seed = 333, n.sims = 2000)
-  expect_equal(mean(abs(as.data.frame(rezpred)$CI_low - rez_merTools$lwr)), 0, tolerance = 0.5)
-
+  expect_equal(
+    mean(abs(as.data.frame(rezpred)$CI_low - rez_merTools$lwr)),
+    0,
+    tolerance = 0.5
+  )
 
   # Compare to emmeans (not sure what it does)
   # refgrid <- emmeans::ref_grid(x, at = as.list(get_data(x)), data = get_data(x))
@@ -232,16 +273,23 @@ test_that("get_predicted - lmerMod", {
   # expect_equal(mean(as.data.frame(rez)$CI_low - rez_emmeans$lower.PL), 0, tolerance = 0.5)
 
   # Compare with glmmTMB
-  ref <- get_predicted(glmmTMB::glmmTMB(mpg ~ am + (1 | cyl), data = mtcars), predict = "expectation", ci = 0.95)
+  ref <- get_predicted(
+    glmmTMB::glmmTMB(mpg ~ am + (1 | cyl), data = mtcars),
+    predict = "expectation",
+    ci = 0.95
+  )
   expect_equal(mean(abs(rezrela - ref)), 0, tolerance = 0.1) # A bit high
   # expect_equal(mean(abs(as.data.frame(rezrela)$SE - as.data.frame(ref)$SE)), 0, tolerance = 1e-5)
   # expect_equal(mean(abs(as.data.frame(rezrela)$CI_low - as.data.frame(ref)$CI_low)), 0, tolerance = 1e-5)
 
   # Compare with rstanarm
   xref <- suppressWarnings(
-    rstanarm::stan_lmer(mpg ~ am + (1 | cyl),
+    rstanarm::stan_lmer(
+      mpg ~ am + (1 | cyl),
       data = mtcars,
-      refresh = 0, iter = 1000, seed = 333
+      refresh = 0,
+      iter = 1000,
+      seed = 333
     )
   )
   rez_stan <- get_predicted(xref, predict = "expectation", ci = 0.95)
@@ -256,7 +304,8 @@ test_that("get_predicted - glmer with matrix response", {
   data(cbpp, package = "lme4")
   model <- lme4::glmer(
     cbind(incidence, size - incidence) ~ period + (1 | herd),
-    data = cbpp, family = binomial
+    data = cbpp,
+    family = binomial
   )
   grid <- get_datagrid(model, by = "period", range = "grid", preserve_range = FALSE)
   out <- as.data.frame(get_predicted(model, data = grid, ci = 0.95))
@@ -292,14 +341,22 @@ test_that("get_predicted - merMod", {
   expect_lt(min(summary(rezlink)$CI_low), 0)
   expect_gt(min(summary(rezrela)$CI_low), 0)
   expect_equal(max(abs(rezrela - stats::fitted(x))), 0, tolerance = 1e-4)
-  expect_equal(max(abs(rezrela - stats::predict(x, type = "response"))), 0, tolerance = 1e-4)
+  expect_equal(
+    max(abs(rezrela - stats::predict(x, type = "response"))),
+    0,
+    tolerance = 1e-4
+  )
   expect_identical(nrow(as.data.frame(rezlink)), 32L)
 
   # Compare with glmmTMB
   xref <- glmmTMB::glmmTMB(vs ~ am + (1 | cyl), data = mtcars, family = "binomial")
   rez_ref <- get_predicted(xref, predict = "expectation", ci = 0.95)
   expect_equal(max(abs(rezrela - rez_ref)), 0, tolerance = 1e-5)
-  expect_equal(mean(abs(as.data.frame(rezrela)$SE - as.data.frame(rez_ref)$SE)), 0, tolerance = 0.2)
+  expect_equal(
+    mean(abs(as.data.frame(rezrela)$SE - as.data.frame(rez_ref)$SE)),
+    0,
+    tolerance = 0.2
+  )
 })
 
 
@@ -311,7 +368,11 @@ test_that("get_predicted - glmmTMB", {
   rezlink <- get_predicted(x, predict = "link", ci = 0.95)
   rezrela <- get_predicted(x, predict = "expectation", ci = 0.95)
   expect_equal(mean(abs(rezlink - rezrela)), 0, tolerance = 1e-3)
-  expect_equal(mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high), 0, tolerance = 1e-3)
+  expect_equal(
+    mean(summary(rezlink)$CI_high - summary(rezrela)$CI_high),
+    0,
+    tolerance = 1e-3
+  )
 
   # Bootstrap
   set.seed(333)
@@ -327,7 +388,11 @@ test_that("get_predicted - glmmTMB", {
   expect_lt(min(summary(rezlink)$CI_low), 0)
   expect_gt(min(summary(rezrela)$CI_low), 0)
   expect_equal(max(abs(rezrela - stats::fitted(x))), 0, tolerance = 1e-4)
-  expect_equal(max(abs(rezrela - stats::predict(x, type = "response"))), 0, tolerance = 1e-4)
+  expect_equal(
+    max(abs(rezrela - stats::predict(x, type = "response"))),
+    0,
+    tolerance = 1e-4
+  )
   expect_identical(nrow(as.data.frame(rez)), 32L)
 
   # No random
@@ -359,7 +424,12 @@ test_that("get_predicted - mgcv::gam and gamm", {
   # No smooth
   rez <- get_predicted(x, data = data.frame(am = c(0, 0, 1)), ci = 0.95)
   expect_length(rez, 3)
-  rez2 <- get_predicted(x, data = data.frame(am = c(0, 0, 1), wt = c(2, 3, 4)), ci = 0.95, include_smooth = FALSE)
+  rez2 <- get_predicted(
+    x,
+    data = data.frame(am = c(0, 0, 1), wt = c(2, 3, 4)),
+    ci = 0.95,
+    include_smooth = FALSE
+  )
   expect_equal(max(abs(as.numeric(rez - rez2))), 0, tolerance = 1e-4)
   expect_length(unique(attributes(rez)$data$wt), 1)
 
@@ -378,11 +448,21 @@ test_that("get_predicted - mgcv::gam and gamm", {
   expect_identical(nrow(as.data.frame(rez)), 32L)
 
   # GAMM
-  x <- mgcv::gamm(vs ~ am + s(wt), random = list(cyl = ~1), data = mtcars, family = "binomial", verbosePQL = FALSE)
+  x <- mgcv::gamm(
+    vs ~ am + s(wt),
+    random = list(cyl = ~1),
+    data = mtcars,
+    family = "binomial",
+    verbosePQL = FALSE
+  )
   rez <- get_predicted(x, ci = 0.95)
   expect_length(rez, 32)
   expect_equal(max(abs(rez - x$gam$fitted.values)), 0, tolerance = 1e-4)
-  expect_equal(max(abs(rez - stats::predict(x$gam, type = "response"))), 0, tolerance = 1e-4)
+  expect_equal(
+    max(abs(rez - stats::predict(x$gam, type = "response"))),
+    0,
+    tolerance = 1e-4
+  )
   expect_identical(nrow(as.data.frame(rez)), 32L)
 })
 
@@ -390,12 +470,15 @@ test_that("get_predicted - mgcv::gam and gamm", {
 # Bayesian --------------------------------------------------------------
 # =========================================================================
 
-
 test_that("get_predicted - rstanarm", {
   skip_if_not_installed("rstanarm")
 
   suppressPackageStartupMessages({
-    suppressWarnings(suppressMessages(library(rstanarm, quietly = TRUE, warn.conflicts = FALSE))) # nolint
+    suppressWarnings(suppressMessages(library(
+      rstanarm,
+      quietly = TRUE,
+      warn.conflicts = FALSE
+    ))) # nolint
   })
 
   # LM
@@ -409,7 +492,13 @@ test_that("get_predicted - rstanarm", {
   expect_true(all(mean(rezlink$CI_high - rezpred$CI_high) < 0))
 
   # GLM
-  x <- rstanarm::stan_glm(vs ~ wt, data = mtcars, family = "binomial", refresh = 0, seed = 333)
+  x <- rstanarm::stan_glm(
+    vs ~ wt,
+    data = mtcars,
+    family = "binomial",
+    refresh = 0,
+    seed = 333
+  )
   rezlink <- summary(get_predicted(x, predict = "link", ci = 0.95))
   rezrela <- summary(get_predicted(x, predict = "expectation", ci = 0.95))
   expect_lt(min(rezlink$Predicted), 0)
@@ -422,34 +511,68 @@ test_that("get_predicted - rstanarm", {
 
   # Mixed
   x <- suppressWarnings(
-    rstanarm::stan_lmer(mpg ~ am + (1 | cyl),
-      data = mtcars, refresh = 0,
-      seed = 333, iter = 500
+    rstanarm::stan_lmer(
+      mpg ~ am + (1 | cyl),
+      data = mtcars,
+      refresh = 0,
+      seed = 333,
+      iter = 500
     )
   )
   rezrela <- summary(get_predicted(x, predict = "expectation", ci = 0.95))
   rezpred <- summary(get_predicted(x, predict = "prediction", ci = 0.95))
-  rezrela2 <- summary(get_predicted(x, predict = "expectation", ci = 0.95, include_random = FALSE))
-  rezpred2 <- summary(get_predicted(x, predict = "prediction", ci = 0.95, include_random = FALSE))
+  rezrela2 <- summary(get_predicted(
+    x,
+    predict = "expectation",
+    ci = 0.95,
+    include_random = FALSE
+  ))
+  rezpred2 <- summary(get_predicted(
+    x,
+    predict = "prediction",
+    ci = 0.95,
+    include_random = FALSE
+  ))
   expect_gt(mean(abs(rezrela$Predicted - rezrela2$Predicted)), 0)
   expect_gt(mean(abs(rezpred$Predicted - rezpred2$Predicted)), 0)
-  rezrela3 <- summary(get_predicted(x, predict = "expectation", ci = 0.95, data = mtcars["am"]), verbose = FALSE)
+  rezrela3 <- summary(
+    get_predicted(x, predict = "expectation", ci = 0.95, data = mtcars["am"]),
+    verbose = FALSE
+  )
   expect_equal(mean(abs(rezrela2$Predicted - rezrela3$Predicted)), 0, tolerance = 0.001)
 })
 
 
 test_that("get_predicted - brms, auxiliary", {
+  skip_if_not_installed("curl")
+  skip_if_offline()
   skip_if_not_installed("brms")
   skip_if_not_installed("httr2")
+  skip_if_not_installed("BH")
+  skip_if_not_installed("RcppEigen")
 
   m <- insight::download_model("brms_sigma_2")
+  skip_if(is.null(m))
+
   dg <- get_datagrid(m, reference = "grid", include_random = TRUE)
   out <- get_predicted(m, data = dg, predict = "sigma")
   expect_equal(
     as.numeric(out),
     c(
-      1.02337, 0.82524, 0.58538, 0.74573, 0.66292, 1.0336, 0.94714,
-      0.74541, 0.71533, 0.7032, 0.63151, 0.65244, 0.58731, 0.45177,
+      1.02337,
+      0.82524,
+      0.58538,
+      0.74573,
+      0.66292,
+      1.0336,
+      0.94714,
+      0.74541,
+      0.71533,
+      0.7032,
+      0.63151,
+      0.65244,
+      0.58731,
+      0.45177,
       0.75789
     ),
     tolerance = 1e-4
@@ -458,14 +581,24 @@ test_that("get_predicted - brms, auxiliary", {
 
 
 test_that("get_predicted - brms, categorical family", {
+  skip_if_not_installed("curl")
+  skip_if_offline()
   skip_if_not_installed("brms")
   skip_if_not_installed("httr2")
+  skip_if_not_installed("BH")
+  skip_if_not_installed("RcppEigen")
 
   suppressPackageStartupMessages({
-    suppressWarnings(suppressMessages(library(brms, quietly = TRUE, warn.conflicts = FALSE))) # nolint
+    suppressWarnings(suppressMessages(library(
+      brms,
+      quietly = TRUE,
+      warn.conflicts = FALSE
+    ))) # nolint
   })
 
   m <- insight::download_model("brms_categorical_1_fct")
+  skip_if(is.null(m))
+
   out <- get_predicted(m, data = get_datagrid(m))
   expect_identical(ncol(out), 4L)
   expect_identical(nrow(out), 30L)
@@ -511,7 +644,11 @@ test_that("lm: get_predicted vs barebones `predict()`", {
   known <- predict(mod, se.fit = TRUE, interval = "confidence")
   unknown1 <- as.data.frame(get_predicted(mod, ci = 0.95))
   unknown2 <- as.data.frame(get_predicted(mod, ci = 0.95, predict = "expectation"))
-  unknown3 <- suppressWarnings(as.data.frame(get_predicted(mod, ci = 0.95, predict = "response")))
+  unknown3 <- suppressWarnings(as.data.frame(get_predicted(
+    mod,
+    ci = 0.95,
+    predict = "response"
+  )))
   expect_equal(unknown1$Predicted, known$fit[, "fit"], ignore_attr = TRUE)
   expect_equal(unknown1$SE, known$se.fit, ignore_attr = TRUE)
   expect_equal(unknown1$CI_low, known$fit[, "lwr"], ignore_attr = TRUE)
@@ -551,7 +688,12 @@ test_that("`predict()` vs. `get_predicted` link equivalence", {
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
   known <- predict(mod, type = "response", se.fit = TRUE)
   unknown1 <- as.data.frame(get_predicted(mod, predict = "expectation", ci = 0.95))
-  unknown2 <- as.data.frame(get_predicted(mod, predict = NULL, type = "response", ci = 0.95))
+  unknown2 <- as.data.frame(get_predicted(
+    mod,
+    predict = NULL,
+    type = "response",
+    ci = 0.95
+  ))
   unknown3 <- as.data.frame(get_predicted(mod, predict = "response", ci = 0.95))
   expect_equal(unname(known$fit), unknown1$Predicted, ignore_attr = TRUE)
   expect_equal(unname(known$se.fit), unknown1$SE, ignore_attr = TRUE)
@@ -570,7 +712,12 @@ test_that("hurdle: get_predicted matches `predict()`", {
   unknown <- get_predicted(mod, predict = "response", ci = 0.95, verbose = FALSE)
   expect_equal(known, unknown, ignore_attr = TRUE)
   known <- predict(mod, type = "zero")
-  unknown <- suppressWarnings(get_predicted(mod, predict = "zero", ci = 0.95, verbose = FALSE))
+  unknown <- suppressWarnings(get_predicted(
+    mod,
+    predict = "zero",
+    ci = 0.95,
+    verbose = FALSE
+  ))
   expect_equal(known, unknown, ignore_attr = TRUE)
 })
 
@@ -579,7 +726,12 @@ test_that("bugfix: used to return all zeros", {
   mod <- glm(am ~ hp + factor(cyl), family = binomial, data = mtcars)
   pred <- get_predicted(mod, predict = "response", ci = 0.95, verbose = FALSE)
   expect_false(any(pred == 0))
-  expect_error(expect_warning(get_predicted(mod, predict = "original", ci = 0.95, verbose = FALSE)))
+  expect_error(expect_warning(get_predicted(
+    mod,
+    predict = "original",
+    ci = 0.95,
+    verbose = FALSE
+  )))
 })
 
 # Original Error: "variables were specified with different types from the fit"
@@ -594,9 +746,16 @@ test_that("bugfix: used to fail with matrix variables", {
   }
   pred <- get_predicted(foo())
   expect_s3_class(pred, c("get_predicted", "numeric"))
-  expect_true(all(attributes(attributes(attributes(
-    pred
-  )$data)$terms)$dataClasses == "numeric"))
+  expect_true(all(
+    attributes(
+      attributes(
+        attributes(
+          pred
+        )$data
+      )$terms
+    )$dataClasses ==
+      "numeric"
+  ))
 
   # Now verify with the data in the same environment
   mtcars2 <- mtcars
@@ -618,9 +777,14 @@ test_that("brms: `type` in ellipsis used to produce the wrong intervals", {
   skip_on_os(os = "windows")
   void <- capture.output(
     suppressMessages({
-      mod <- brms::brm(am ~ hp + mpg,
-        family = brms::bernoulli, data = mtcars,
-        chains = 2, iter = 1000, seed = 1024, silent = 2
+      mod <- brms::brm(
+        am ~ hp + mpg,
+        family = brms::bernoulli,
+        data = mtcars,
+        chains = 2,
+        iter = 1000,
+        seed = 1024,
+        silent = 2
       )
     })
   )
@@ -635,7 +799,8 @@ test_that("brms: `type` in ellipsis used to produce the wrong intervals", {
   data$cyl <- as.character(data$cyl)
   void <- capture.output(
     suppressMessages(suppressWarnings({
-      model <- brms::brm(cyl ~ mpg * vs + (1 | carb),
+      model <- brms::brm(
+        cyl ~ mpg * vs + (1 | carb),
         data = data,
         iter = 1000,
         seed = 1024,
@@ -649,7 +814,12 @@ test_that("brms: `type` in ellipsis used to produce the wrong intervals", {
   # Test shape
   expect_identical(c(nrow(x), ncol(x)), c(96L, 1010L))
   # Test whether median point-estimate indeed different from default (mean)
-  expect_gt(max(x$Predicted - get_predicted(model, centrality_function = stats::median)$Predicted), 0)
+  expect_gt(
+    max(
+      x$Predicted - get_predicted(model, centrality_function = stats::median)$Predicted
+    ),
+    0
+  )
   # predictions include variables from data grid
   x <- get_predicted(model, ci = 0.95)
   expect_named(x, c("Row", "Response", "cyl", "mpg", "vs", "carb", "Predicted"))
@@ -728,15 +898,32 @@ test_that("get_predicted works with brms-Wiener", {
   expect_named(
     as.data.frame(out),
     c(
-      "Row", "Component", "rt", "response", "Predicted", "SE", "CI_low",
-      "CI_high", "iter_1", "iter_2", "iter_3"
+      "Row",
+      "Component",
+      "rt",
+      "response",
+      "Predicted",
+      "SE",
+      "CI_low",
+      "CI_high",
+      "iter_1",
+      "iter_2",
+      "iter_3"
     )
   )
   expect_identical(
     as.data.frame(out)$Component,
     c(
-      "rt", "rt", "rt", "rt", "rt", "response", "response", "response",
-      "response", "response"
+      "rt",
+      "rt",
+      "rt",
+      "rt",
+      "rt",
+      "response",
+      "response",
+      "response",
+      "response",
+      "response"
     )
   )
   expect_true(model_info(m)$is_wiener)
