@@ -7,7 +7,8 @@ test_that("informative error in get_varcov.default", {
   # sandwich: not supported
   expect_error(get_varcov(mod, vcov = "HC2"))
   # clubSandwich: supported
-  expect_equal(get_varcov(mod, vcov = "CR0"),
+  expect_equal(
+    get_varcov(mod, vcov = "CR0"),
     clubSandwich::vcovCR(mod, type = "CR0"),
     tolerance = 1e-4,
     ignore_attr = TRUE
@@ -32,7 +33,8 @@ test_that("lm: sandwich", {
     sandwich::vcovHC(mod, type = "HC4"),
     ignore_attr = TRUE
   )
-  expect_equal(get_varcov(mod, vcov = sandwich::vcovOPG),
+  expect_equal(
+    get_varcov(mod, vcov = sandwich::vcovOPG),
     sandwich::vcovOPG(mod),
     tolerance = 1e-5
   )
@@ -152,10 +154,7 @@ test_that("glmmTMB: sandwich", {
 test_that("lm: clubSandwich", {
   mod <- lm(mpg ~ hp * wt, data = mtcars)
   expect_equal(
-    get_varcov(mod,
-      vcov = "CR",
-      vcov_args = list(cluster = mtcars$cyl, type = "CR0")
-    ),
+    get_varcov(mod, vcov = "CR", vcov_args = list(cluster = mtcars$cyl, type = "CR0")),
     clubSandwich::vcovCR(mod, cluster = mtcars$cyl, type = "CR0"),
     tolerance = 1e-5,
     ignore_attr = TRUE
